==> ldap-account-manager_3.6.orig.tar.gz: ldap-account-manager-3.6/templates/lib/141_jquery-validationEngine-lang.php <==
<?php
/*
$Id: 141_jquery-validationEngine-lang.php,v 1.1 2011/10/16 12:04:31 gruberroland Exp $

  This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
  Copyright (C) 2010  Cedric Dugas and Olivier Refalo
                2011  Roland Gruber

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/
?>

(function($){
    $.fn.validationEngineLanguage = function(){
    };
    $.validationEngineLanguage = {
        newLang: function(){
            $.validationEngineLanguage.allRules = {
                "required": {
                    "regex": "none",
                    "alertText": "<?php echo _('This field is required.'); ?>",
                },
                "numeric": {
                    "regex": /^[0-9]+$/,
                    "alertText": "<?php echo _('Please enter a number.') ?>"
                },
            };
        }
    };
    $.validationEngineLanguage.newLang();
})(jQuery);

==> ldap-account-manager_4.0.1.orig.tar.gz: ldap-account-manager-4.0.1/templates/lib/141_jquery-validationEngine-lang.php <==
<?php
/*
$Id: 141_jquery-validationEngine-lang.php,v 1.3 2012/10/21 13:31:25 gruberroland Exp $

  This code is part of LDAP Account Manager (http://www.ldap-account-manager.org/)
  Copyright (C) 2010         Cedric Dugas and Olivier Refalo
                2011 - 2012  Roland Gruber

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/
?>

(function($){
    $.fn.validationEngineLanguage = function(){
    };
    $.validationEngineLanguage = {
        newLang: function(){
            $.validationEngineLanguage.allRules = {
                "required": {
                    "regex": "none",
                    "alertText": "<?php echo _('This field is required.'); ?>"
                },
                "numeric": {
                    "regex": /^[0-9]+$/,
                    "alertText": "<?php echo _('Please enter a number.') ?>"
                }
            };
        }
    };
    $.validationEngineLanguage.newLang();
})(jQuery);
